public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Gary Lin <glin@suse.com>
To: edk2-devel@lists.01.org
Cc: Siyuan Fu <siyuan.fu@intel.com>, Jiaxin Wu <jiaxin.wu@intel.com>
Subject: [PATCH 23/33] NetworkPkg: Fix typos in comments
Date: Wed, 19 Oct 2016 15:01:28 +0800	[thread overview]
Message-ID: <20161019070138.16424-24-glin@suse.com> (raw)
In-Reply-To: <20161019070138.16424-1-glin@suse.com>

- assocated -> associated
- malformated -> malformatted
- mal-formated -> mal-formatted
- formated -> formatted
- octects -> octets
- responsiblity -> responsibility
- enought -> enough
- immediatly -> immediately
- integar -> integer
- Alogrithem -> Algorithm
- Initializeion -> Initialization
- primelenght -> primelength
- Vlaue -> Value
- perfoms -> performs
- randome -> random
- verifed -> verified
- finallization -> finalization
- Intializes -> Initializes
- specifed -> specified
- if -> If
- Decrption -> Decryption
- Autahentication -> Authentication
- informatino -> information
- alogrithm -> algorithm
- Authenticaion -> Authentication
- Alogrithem -> Algorithm
- containning -> containing
- paramter -> parameter

Cc: Siyuan Fu <siyuan.fu@intel.com>
Cc: Jiaxin Wu <jiaxin.wu@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Gary Lin <glin@suse.com>
---
 NetworkPkg/Application/Ping6/Ping6.c |  8 +--
 NetworkPkg/IScsiDxe/IScsiProto.c     |  4 +-
 NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c    |  2 +-
 NetworkPkg/Ip6Dxe/Ip6Option.c        | 16 ++---
 NetworkPkg/Ip6Dxe/Ip6Option.h        | 10 +--
 NetworkPkg/Ip6Dxe/Ip6Output.c        |  8 +--
 NetworkPkg/IpSecDxe/IpSecCryptIo.c   | 50 +++++++--------
 NetworkPkg/IpSecDxe/IpSecCryptIo.h   | 66 ++++++++++----------
 8 files changed, 82 insertions(+), 82 deletions(-)

diff --git a/NetworkPkg/Application/Ping6/Ping6.c b/NetworkPkg/Application/Ping6/Ping6.c
index 55314e5..66daac2 100644
--- a/NetworkPkg/Application/Ping6/Ping6.c
+++ b/NetworkPkg/Application/Ping6/Ping6.c
@@ -1103,7 +1103,7 @@ InitializePing6 (
   BufferSize = 16;
 
   //
-  // Parse the paramter of count number.
+  // Parse the parameter of count number.
   //
   ValueStr = ShellCommandLineGetValue (ParamPackage, L"-n");
   ValueStrPtr = ValueStr;
@@ -1120,7 +1120,7 @@ InitializePing6 (
     }
   }
   //
-  // Parse the paramter of buffer size.
+  // Parse the parameter of buffer size.
   //
   ValueStr = ShellCommandLineGetValue (ParamPackage, L"-l");
   ValueStrPtr = ValueStr;
@@ -1141,7 +1141,7 @@ InitializePing6 (
   ZeroMem (&DstAddress, sizeof (EFI_IPv6_ADDRESS));
 
   //
-  // Parse the paramter of source ip address.
+  // Parse the parameter of source ip address.
   //
   ValueStr = ShellCommandLineGetValue (ParamPackage, L"-s");
   ValueStrPtr = ValueStr;
@@ -1155,7 +1155,7 @@ InitializePing6 (
     }
   }
   //
-  // Parse the paramter of destination ip address.
+  // Parse the parameter of destination ip address.
   //
   NonOptionCount = ShellCommandLineGetCount(ParamPackage);
   ValueStr = ShellCommandLineGetRawValue (ParamPackage, (UINT32)(NonOptionCount-1));
diff --git a/NetworkPkg/IScsiDxe/IScsiProto.c b/NetworkPkg/IScsiDxe/IScsiProto.c
index 88d9bdd..eb77d75 100644
--- a/NetworkPkg/IScsiDxe/IScsiProto.c
+++ b/NetworkPkg/IScsiDxe/IScsiProto.c
@@ -786,7 +786,7 @@ IScsiPrepareLoginReq (
 
   case ISCSI_LOGIN_OPERATIONAL_NEGOTIATION:
     //
-    // Only negotiate the paramter once.
+    // Only negotiate the parameter once.
     //
     if (!Conn->ParamNegotiated) {
       IScsiFillOpParams (Conn, Nbuf);
@@ -2117,7 +2117,7 @@ IScsiNewDataSegment (
 
   @param[in]  Packet The EXT SCSI PASS THRU request packet containing the SCSI command.
   @param[in]  Lun    The LUN.
-  @param[in]  Tcb    The tcb assocated with this SCSI command.
+  @param[in]  Tcb    The tcb associated with this SCSI command.
 
   @return The  created iSCSI SCSI command PDU.
   @retval NULL Other errors as indicated.
diff --git a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
index 75ecec1..9b6a62e 100644
--- a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
+++ b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
@@ -121,7 +121,7 @@ Ip6ConfigOnPolicyChanged (
 
   if (NewPolicy == Ip6ConfigPolicyAutomatic) {
     //
-    // Set paramters to trigger router solicitation sending in timer handler.
+    // Set parameters to trigger router solicitation sending in timer handler.
     //
     IpSb->RouterAdvertiseReceived = FALSE;
     IpSb->SolicitTimer            = IP6_MAX_RTR_SOLICITATIONS;
diff --git a/NetworkPkg/Ip6Dxe/Ip6Option.c b/NetworkPkg/Ip6Dxe/Ip6Option.c
index 9a91fd7..21d28b6 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Option.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Option.c
@@ -18,7 +18,7 @@
 /**
   Validate the IP6 option format for both the packets we received
   and that we will transmit. It will compute the ICMPv6 error message fields
-  if the option is malformated.
+  if the option is malformatted.
 
   @param[in]  IpSb              The IP6 service data.
   @param[in]  Packet            The to be validated packet.
@@ -29,7 +29,7 @@
 
 
   @retval TRUE     The option is properly formatted.
-  @retval FALSE    The option is malformated.
+  @retval FALSE    The option is malformatted.
 
 **/
 BOOLEAN
@@ -126,7 +126,7 @@ Ip6IsOptionValid (
   @param[in]  OptionLen         The length of the whole option.
 
   @retval TRUE     The option is properly formatted.
-  @retval FALSE    The option is malformated.
+  @retval FALSE    The option is malformatted.
 
 **/
 BOOLEAN
@@ -231,7 +231,7 @@ Ip6IsValidProtocol (
 /**
   Validate the IP6 extension header format for both the packets we received
   and that we will transmit. It will compute the ICMPv6 error message fields
-  if the option is mal-formated.
+  if the option is mal-formatted.
 
   @param[in]  IpSb          The IP6 service instance. This is an optional parameter.
   @param[in]  Packet        The data of the packet. Ignored if NULL.
@@ -252,8 +252,8 @@ Ip6IsValidProtocol (
   @param[out] Fragmented    Indicate whether the packet is fragmented.
                             This is an optional parameter that may be NULL.
 
-  @retval     TRUE          The option is properly formated.
-  @retval     FALSE         The option is malformated.
+  @retval     TRUE          The option is properly formatted.
+  @retval     FALSE         The option is malformatted.
 
 **/
 BOOLEAN
@@ -436,7 +436,7 @@ Ip6IsExtsValid (
 
       //
       // RFC2460, ICMP Parameter Problem message with code 0 should be sent
-      // if the length of a fragment is not a multiple of 8 octects and the M
+      // if the length of a fragment is not a multiple of 8 octets and the M
       // flag of that fragment is 1, pointing to the Payload length field of the
       // fragment packet.
       //
@@ -606,7 +606,7 @@ Ip6FillHopByHop (
   @param[in]  ExtHdrsLen       The length of the extension headers.
   @param[in]  FragmentOffset   The fragment offset of the data following the header.
   @param[out] UpdatedExtHdrs   The updated ExtHdrs with Fragment header inserted.
-                               It's caller's responsiblity to free this buffer.
+                               It's caller's responsibility to free this buffer.
 
   @retval EFI_OUT_OF_RESOURCES Failed to finish the operation due to lake of
                                resource.
diff --git a/NetworkPkg/Ip6Dxe/Ip6Option.h b/NetworkPkg/Ip6Dxe/Ip6Option.h
index b62a042..242ec51 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Option.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Option.h
@@ -51,7 +51,7 @@ typedef enum {
 /**
   Validate the IP6 extension header format for both the packets we received
   and that we will transmit. It will compute the ICMPv6 error message fields
-  if the option is mal-formated.
+  if the option is mal-formatted.
 
   @param[in]  IpSb          The IP6 service instance. This is an optional parameter.
   @param[in]  Packet        The data of the packet. Ignored if NULL.
@@ -72,8 +72,8 @@ typedef enum {
   @param[out] Fragmented    Indicate whether the packet is fragmented.
                             This is an optional parameter that may be NULL.
 
-  @retval     TRUE          The option is properly formated.
-  @retval     FALSE         The option is malformated.
+  @retval     TRUE          The option is properly formatted.
+  @retval     FALSE         The option is malformatted.
 
 **/
 BOOLEAN
@@ -122,7 +122,7 @@ Ip6FillHopByHop (
   @param[in]  ExtHdrsLen       The length of the extension headers.
   @param[in]  FragmentOffset   The fragment offset of the data following the header.
   @param[out] UpdatedExtHdrs   The updated ExtHdrs with Fragment header inserted.
-                               It's caller's responsiblity to free this buffer.
+                               It's caller's responsibility to free this buffer.
 
   @retval EFI_OUT_OF_RESOURCES Failed to finish the operation due to lake of
                                resource.
@@ -179,7 +179,7 @@ Ip6CopyExts (
   @param[in]  OptionLen         The length of the whole option.
 
   @retval TRUE     The option is properly formatted.
-  @retval FALSE    The option is malformated.
+  @retval FALSE    The option is malformatted.
 
 **/
 BOOLEAN
diff --git a/NetworkPkg/Ip6Dxe/Ip6Output.c b/NetworkPkg/Ip6Dxe/Ip6Output.c
index fe642d3..8330e37 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Output.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Output.c
@@ -23,7 +23,7 @@ UINT32 mIp6Id;
 
   @param[in]       IpSb             Points to an IP6 service binding instance.
   @param[out]      SourceList       The list entry head of all source addresses.
-                                    It is the caller's responsiblity to free the
+                                    It is the caller's responsibility to free the
                                     resources.
   @param[out]      SourceCount      The number of source addresses.
 
@@ -364,7 +364,7 @@ Ip6SysPacketSent (
   @param[in]  LastHeader       The pointer of next header of last extension header.
   @param[in]  HeadLen          The length of the unfragmented part of the IP6 header.
 
-  @retval EFI_BAD_BUFFER_SIZE  There is no enought room in the head space of
+  @retval EFI_BAD_BUFFER_SIZE  There is no enough room in the head space of
                                Packet.
   @retval EFI_SUCCESS          The operation performed successfully.
 
@@ -726,7 +726,7 @@ Ip6Output (
       }
 
       //
-      // Send out multicast neighbor solicitation for address resolution immediatly.
+      // Send out multicast neighbor solicitation for address resolution immediately.
       //
       Ip6CreateSNMulticastAddr (&NeighborCache->Neighbor, &Destination);
       Status = Ip6SelectSourceAddress (IpSb, &NeighborCache->Neighbor, &Source);
@@ -809,7 +809,7 @@ Ip6Output (
   //
   // OK, selected the source and route, fragment the packet then send
   // them. Tag each fragment other than the first one as spawn from it.
-  // Each extension header is an integar multiple of 8 octets long, in
+  // Each extension header is an integer multiple of 8 octets long, in
   // order to retain 8-octet alignment for subsequent headers.
   //
   Mtu     = IpSb->MaxPacketSize + sizeof (EFI_IP6_HEADER);
diff --git a/NetworkPkg/IpSecDxe/IpSecCryptIo.c b/NetworkPkg/IpSecDxe/IpSecCryptIo.c
index dca4423..31fa4fb 100644
--- a/NetworkPkg/IpSecDxe/IpSecCryptIo.c
+++ b/NetworkPkg/IpSecDxe/IpSecCryptIo.c
@@ -45,7 +45,7 @@ GLOBAL_REMOVE_IF_UNREFERENCED HASH_ALGORITHM mIpsecHashAlgorithmList[IPSEC_HASH_
 BOOLEAN  mInitialRandomSeed = FALSE;
 
 /**
-  Get the block size of specified encryption alogrithm.
+  Get the block size of specified encryption algorithm.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -69,7 +69,7 @@ IpSecGetEncryptBlockSize (
 }
 
 /**
-  Get the key length of the specified encryption alogrithm.
+  Get the key length of the specified encryption algorithm.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -93,7 +93,7 @@ IpSecGetEncryptKeyLength (
 }
 
 /**
-  Get the IV size of the specified encryption alogrithm.
+  Get the IV size of the specified encryption algorithm.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -144,7 +144,7 @@ IpSecGetHmacDigestLength (
 }
 
 /**
-  Get the ICV size of the specified Authenticaion alogrithm.
+  Get the ICV size of the specified Authenticaion algorithm.
 
   @param[in]  AlgorithmId          The Authentication algorithm ID.
 
@@ -191,7 +191,7 @@ IpSecGenerateIv (
 }
 
 /**
-  Get index of the specified encryption alogrithm from the mIpsecEncryptAlgorithemList.
+  Get index of the specified encryption algorithm from the mIpsecEncryptAlgorithmList.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -215,7 +215,7 @@ IpSecGetIndexFromEncList (
 }
 
 /**
-  Get index of the specified encryption alogrithm from the mIpsecAuthAlgorithemList.
+  Get index of the specified encryption algorithm from the mIpsecAuthAlgorithmList.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -245,14 +245,14 @@ IpSecGetIndexFromAuthList (
   Encrypt the buffer.
 
   This function calls relevant encryption interface from CryptoLib according to
-  the input alogrithm ID. The InData should be multiple of block size. This function
+  the input algorithm ID. The InData should be multiple of block size. This function
   doesn't perform the padding. If it has the Ivec data, the length of it should be
   same with the block size. The block size is different from the different algorithm.
 
-  @param[in]       AlgorithmId    The Alogrithem identification defined in RFC.
+  @param[in]       AlgorithmId    The Algorithm identification defined in RFC.
   @param[in]       Key            Pointer to the buffer containing encrypting key.
   @param[in]       KeyBits        The length of the key in bits.
-  @param[in]       Ivec           Point to the buffer containning the Initializeion
+  @param[in]       Ivec           Point to the buffer containing the Initialization
                                   Vector (IV) data.
   @param[in]       InData         Point to the buffer containing the data to be
                                   encrypted.
@@ -331,14 +331,14 @@ IpSecCryptoIoEncrypt (
   Decrypts the buffer.
 
   This function calls relevant Decryption interface from CryptoLib according to
-  the input alogrithm ID. The InData should be multiple of block size. This function
+  the input algorithm ID. The InData should be multiple of block size. This function
   doesn't perform the padding. If it has the Ivec data, the length of it should be
   same with the block size. The block size is different from the different algorithm.
 
-  @param[in]       AlgorithmId    The Alogrithem identification defined in RFC.
+  @param[in]       AlgorithmId    The Algorithm identification defined in RFC.
   @param[in]       Key            Pointer to the buffer containing encrypting key.
   @param[in]       KeyBits        The length of the key in bits.
-  @param[in]       Ivec           Point to the buffer containning the Initializeion
+  @param[in]       Ivec           Point to the buffer containing the Initialization
                                   Vector (IV) data.
   @param[in]       InData         Point to the buffer containing the data to be
                                   decrypted.
@@ -417,9 +417,9 @@ IpSecCryptoIoDecrypt (
   Digests the Payload with key and store the result into the OutData.
 
   This function calls relevant Hmac interface from CryptoLib according to
-  the input alogrithm ID. It computes all datas from InDataFragment and output
+  the input algorithm ID. It computes all datas from InDataFragment and output
   the result into the OutData buffer. If the OutDataSize is larger than the related
-  HMAC alogrithm output size, return EFI_INVALID_PARAMETER.
+  HMAC algorithm output size, return EFI_INVALID_PARAMETER.
   
   @param[in]      AlgorithmId     The authentication Identification.
   @param[in]      Key             Pointer of the authentication key.
@@ -540,9 +540,9 @@ Exit:
   Digests the Payload and store the result into the OutData.
 
   This function calls relevant Hash interface from CryptoLib according to
-  the input alogrithm ID. It computes all datas from InDataFragment and output
+  the input algorithm ID. It computes all datas from InDataFragment and output
   the result into the OutData buffer. If the OutDataSize is larger than the related
-  Hash alogrithm output size, return EFI_INVALID_PARAMETER.
+  Hash algorithm output size, return EFI_INVALID_PARAMETER.
 
   @param[in]      AlgorithmId     The authentication Identification.
   @param[in]      InDataFragment  A list contains all data to be authenticated.
@@ -657,14 +657,14 @@ Exit:
   Generates the Diffie-Hellman public key.
 
   This function first initiate a DHContext, then call the DhSetParameter() to set
-  the prime and primelenght, at end call the DhGenerateKey() to generates random
+  the prime and primelength, at end call the DhGenerateKey() to generates random
   secret exponent, and computes the public key. The output returned via parameter
   PublicKey and PublicKeySize. DH context is updated accordingly. If the PublicKey
   buffer is too small to hold the public key, EFI_INVALID_PARAMETER is returned
   and PublicKeySize is set to the required buffer size to obtain the public key.
 
   @param[in, out] DhContext       Pointer to the DH context.
-  @param[in]      Generator       Vlaue of generator.
+  @param[in]      Generator       Value of generator.
   @param[in]      PrimeLength     Length in bits of prime to be generated.
   @param[in]      Prime           Pointer to the buffer to receive the generated
                                   prime number.
@@ -673,7 +673,7 @@ Exit:
                                   For out, the size of data returned in PublicKey
                                   buffer in bytes.
 
-  @retval EFI_SUCCESS             The operation perfoms successfully.
+  @retval EFI_SUCCESS             The operation performs successfully.
   @retval Otherwise               The operation is failed.
 
 **/
@@ -725,7 +725,7 @@ Exit:
                                     For out, the size of data returned in Key
                                     buffer in bytes.
 
-  @retval EFI_SUCCESS              The operation perfoms successfully.
+  @retval EFI_SUCCESS              The operation performs successfully.
   @retval Otherwise                The operation is failed.
 
 **/
@@ -750,7 +750,7 @@ IpSecCryptoIoDhComputeKey (
 
   @param[in, out]     DhContext         Pointer to the DH context to be freed.
 
-  @retval EFI_SUCCESS              The operation perfoms successfully.
+  @retval EFI_SUCCESS              The operation performs successfully.
   @retval EFI_INVALID_PARAMETER    The DhContext is NULL.
   
 **/
@@ -773,9 +773,9 @@ IpSecCryptoIoFreeDh (
   If the Random Generator wasn't initiated, initiate it first, then call RandomBytes.
 
   @param[out]  OutBuffer        Pointer to buffer to receive random value.
-  @param[in]   Bytes            Size of randome bytes to generate.
+  @param[in]   Bytes            Size of random bytes to generate.
 
-  @retval EFI_SUCCESS              The operation perfoms successfully.
+  @retval EFI_SUCCESS              The operation performs successfully.
   @retval Otherwise                The operation is failed.
 
 **/
@@ -869,9 +869,9 @@ IpSecCryptoIoAuthDataWithCertificate (
   @param[in]     CertLen         The size of Certificate in bytes.
   @param[in]     InCa            Pointer to the CA certificate
   @param[in]     CaLen           The size of CA certificate in bytes.
-  @param[in]     InData          Pointer to octect message hash to be checked.
+  @param[in]     InData          Pointer to octet message hash to be checked.
   @param[in]     InDataSize      Size of the message hash in bytes.
-  @param[in]     Singnature      The pointer to the RSA PKCS1-V1_5 signature to be verifed.
+  @param[in]     Singnature      The pointer to the RSA PKCS1-V1_5 signature to be verified.
   @param[in]     SigSize         Size of signature in bytes.
 
   @retval  TRUE   Valid signature encoded in PKCS1-v1_5.
diff --git a/NetworkPkg/IpSecDxe/IpSecCryptIo.h b/NetworkPkg/IpSecDxe/IpSecCryptIo.h
index 0e106af..0ef83eb 100644
--- a/NetworkPkg/IpSecDxe/IpSecCryptIo.h
+++ b/NetworkPkg/IpSecDxe/IpSecCryptIo.h
@@ -104,7 +104,7 @@ BOOLEAN
   );
 
 /**
-  Prototype of HMAC finallization.
+  Prototype of HMAC finalization.
   Terminate a HMAC message digest operation and output the message digest.
 
   If Context is NULL, then ASSERT().
@@ -139,7 +139,7 @@ UINTN
 
 /**
   Prototype of Block Cipher initiation.
-  Intializes the user-supplied key as the specifed context (key materials) for both
+  Initializes the user-supplied key as the specified context (key materials) for both
   encryption and decryption operations.
 
   If Context is NULL, then ASSERT().
@@ -165,7 +165,7 @@ BOOLEAN
   Encrypts plaintext message with the specified cipher.
 
   If Context is NULL, then ASSERT().
-  if InData is NULL, then ASSERT().
+  If InData is NULL, then ASSERT().
   If Size of input data is not multiple of Cipher algorithm related block size,
   then ASSERT().
 
@@ -193,7 +193,7 @@ BOOLEAN
   Decrypts cipher message with specified cipher.
 
   If Context is NULL, then ASSERT().
-  if InData is NULL, then ASSERT().
+  If InData is NULL, then ASSERT().
   If Size of input data is not a multiple of a certaion block size , then ASSERT().
 
   @param[in]      Context      The specified Context.
@@ -256,7 +256,7 @@ BOOLEAN
 
   This function performs digest on a data buffer of the specified size.
   It can be called multiple times to compute the digest of long or discontinuous data streams.
-  Context should be already correctly intialized by HashInit(), and should not be finalized
+  Context should be already correctly initialized by HashInit(), and should not be finalized
   by HashFinal(). Behavior with invalid context is undefined.
 
   If Context is NULL, then ASSERT().
@@ -285,7 +285,7 @@ BOOLEAN
   This function completes hash computation and retrieves the digest value into
   the specified memory. After this function has been called, the context cannot
   be used again.
-  context should be already correctly intialized by HashInit(), and should not be
+  context should be already correctly initialized by HashInit(), and should not be
   finalized by HashFinal(). Behavior with invalid context is undefined.
 
   If Context is NULL, then ASSERT().
@@ -339,13 +339,13 @@ typedef struct _ENCRYPT_ALGORITHM {
   //
   CRYPTO_CIPHER_ENCRYPT        CipherEncrypt;
   //
-  // The Function pointer of Cipher Decrption.
+  // The Function pointer of Cipher Decryption.
   //
   CRYPTO_CIPHER_DECRYPT        CipherDecrypt;
 } ENCRYPT_ALGORITHM;
 
 //
 // The struct used to store the information and operation of Autahentication algorithm.
 //
 typedef struct _AUTH_ALGORITHM {
   //
@@ -383,7 +383,7 @@ typedef struct _AUTH_ALGORITHM {
 } AUTH_ALGORITHM;
 
 //
-// The struct used to store the informatino and operation of Hash algorithm.
+// The struct used to store the information and operation of Hash algorithm.
 //
 typedef struct _HASH_ALGORITHM {
   //
@@ -421,7 +421,7 @@ typedef struct _HASH_ALGORITHM {
 } HASH_ALGORITHM;
 
 /**
-  Get the IV size of specified encryption alogrithm.
+  Get the IV size of specified encryption algorithm.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -434,7 +434,7 @@ IpSecGetEncryptIvLength (
   );
 
 /**
-  Get the block size of specified encryption alogrithm.
+  Get the block size of specified encryption algorithm.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -447,7 +447,7 @@ IpSecGetEncryptBlockSize (
   );
 
 /**
-  Get the required key length of the specified encryption alogrithm.
+  Get the required key length of the specified encryption algorithm.
 
   @param[in]  AlgorithmId          The encryption algorithm ID.
 
@@ -460,7 +460,7 @@ IpSecGetEncryptKeyLength (
   );
 
 /**
-  Get the ICV size of the specified Authenticaion alogrithm.
+  Get the ICV size of the specified Authentication algorithm.
 
   @param[in]  AlgorithmId          The Authentication algorithm ID.
 
@@ -475,7 +475,7 @@ IpSecGetIcvLength (
 /**
   Get the HMAC digest length by the specified Algorithm ID.
 
-  @param[in]  AlgorithmId  The specified Alogrithm ID.
+  @param[in]  AlgorithmId  The specified Algorithm ID.
 
   @return The digest length of the specified Authentication Algorithm ID.
 
@@ -505,14 +505,14 @@ IpSecGenerateIv (
   Encrypt the buffer.
 
   This function calls relevant encryption interface from CryptoLib according to
-  the input alogrithm ID. The InData should be multiple of block size. This function
+  the input algorithm ID. The InData should be multiple of block size. This function
   doesn't perform the padding. If it has the Ivec data, the length of it should be
   same with the block size. The block size is different from the different algorithm.
 
-  @param[in]       AlgorithmId    The Alogrithem identification defined in RFC.
+  @param[in]       AlgorithmId    The Algorithm identification defined in RFC.
   @param[in]       Key            Pointer to the buffer containing encrypting key.
   @param[in]       KeyBits        The length of the key in bits.
-  @param[in]       Ivec           Point to the buffer containning the Initializeion
+  @param[in]       Ivec           Point to the buffer containing the Initialization
                                   Vector (IV) data.
   @param[in]       InData         Point to the buffer containing the data to be
                                   encrypted.
@@ -540,14 +540,14 @@ IpSecCryptoIoEncrypt (
   Decrypts the buffer.
 
   This function calls relevant Decryption interface from CryptoLib according to
-  the input alogrithm ID. The InData should be multiple of block size. This function
+  the input algorithm ID. The InData should be multiple of block size. This function
   doesn't perform the padding. If it has the Ivec data, the length of it should be
   same with the block size. The block size is different from the different algorithm.
 
-  @param[in]       AlgorithmId    The Alogrithem identification defined in RFC.
+  @param[in]       AlgorithmId    The Algorithm identification defined in RFC.
   @param[in]       Key            Pointer to the buffer containing encrypting key.
   @param[in]       KeyBits        The length of the key in bits.
-  @param[in]       Ivec           Point to the buffer containning the Initializeion
+  @param[in]       Ivec           Point to the buffer containing the Initialization
                                   Vector (IV) data.
   @param[in]       InData         Point to the buffer containing the data to be
                                   decrypted.
@@ -575,9 +575,9 @@ IpSecCryptoIoDecrypt (
   Digests the Payload with key and store the result into the OutData.
 
   This function calls relevant Hmac interface from CryptoLib according to
-  the input alogrithm ID. It computes all datas from InDataFragment and output
+  the input algorithm ID. It computes all datas from InDataFragment and output
   the result into the OutData buffer. If the OutDataSize is larger than the related
-  HMAC alogrithm output size, return EFI_INVALID_PARAMETER.
+  HMAC algorithm output size, return EFI_INVALID_PARAMETER.
   
   @param[in]      AlgorithmId     The authentication Identification.
   @param[in]      Key             Pointer of the authentication key.
@@ -609,9 +609,9 @@ IpSecCryptoIoHmac (
   Digests the Payload and store the result into the OutData.
 
   This function calls relevant Hash interface from CryptoLib according to
-  the input alogrithm ID. It computes all datas from InDataFragment and output
+  the input algorithm ID. It computes all datas from InDataFragment and output
   the result into the OutData buffer. If the OutDataSize is larger than the related
-  Hash alogrithm output size, return EFI_INVALID_PARAMETER.
+  Hash algorithm output size, return EFI_INVALID_PARAMETER.
 
   @param[in]      AlgorithmId     The authentication Identification.
   @param[in]      InDataFragment  A list contains all data to be authenticated.
@@ -640,14 +640,14 @@ IpSecCryptoIoHash (
   Generates the Diffie-Hellman public key.
 
   This function first initiate a DHContext, then call the DhSetParameter() to set
-  the prime and primelenght, at end call the DhGenerateKey() to generates random
+  the prime and primelength, at end call the DhGenerateKey() to generates random
   secret exponent, and computes the public key. The output returned via parameter
   PublicKey and PublicKeySize. DH context is updated accordingly. If the PublicKey
   buffer is too small to hold the public key, EFI_INVALID_PARAMETER is returned
   and PublicKeySize is set to the required buffer size to obtain the public key.
 
   @param[in, out] DhContext       Pointer to the DH context.
-  @param[in]      Generator       Vlaue of generator.
+  @param[in]      Generator       Value of generator.
   @param[in]      PrimeLength     Length in bits of prime to be generated.
   @param[in]      Prime           Pointer to the buffer to receive the generated
                                   prime number.
@@ -656,7 +656,7 @@ IpSecCryptoIoHash (
                                   For out, the size of data returned in PublicKey
                                   buffer in bytes.
 
-  @retval EFI_SUCCESS             The operation perfoms successfully.
+  @retval EFI_SUCCESS             The operation performs successfully.
   @retval Otherwise               The operation is failed.
 
 **/
@@ -684,7 +684,7 @@ IpSecCryptoIoDhGetPublicKey (
                                     For out, the size of data returned in Key
                                     buffer in bytes.
 
-  @retval EFI_SUCCESS              The operation perfoms successfully.
+  @retval EFI_SUCCESS              The operation performs successfully.
   @retval Otherwise                The operation is failed.
 
 **/
@@ -702,7 +702,7 @@ IpSecCryptoIoDhComputeKey (
 
   @param[in, out]     DhContext         Pointer to the DH context to be freed.
 
-  @retval EFI_SUCCESS              The operation perfoms successfully.
+  @retval EFI_SUCCESS              The operation performs successfully.
   @retval EFI_INVALID_PARAMETER    The DhContext is NULL.
   
 **/
@@ -717,9 +717,9 @@ IpSecCryptoIoFreeDh (
   If the Random Generator wasn't initiated, initiate it first, then call RandomBytes.
 
   @param[out]  OutBuffer        Pointer to buffer to receive random value.
-  @param[in]   Bytes            Size of randome bytes to generate.
+  @param[in]   Bytes            Size of random bytes to generate.
 
-  @retval EFI_SUCCESS              The operation perfoms successfully.
+  @retval EFI_SUCCESS              The operation performs successfully.
   @retval Otherwise                The operation is failed.
 
 **/
@@ -762,9 +762,9 @@ IpSecCryptoIoAuthDataWithCertificate (
   @param[in]     CertLen         The size of Certificate in bytes.
   @param[in]     InCa            Pointer to the CA certificate
   @param[in]     CaLen           The size of CA certificate in bytes.
-  @param[in]     InData          Pointer to octect message hash to be checked.
+  @param[in]     InData          Pointer to octet message hash to be checked.
   @param[in]     InDataSize      Size of the message hash in bytes.
-  @param[in]     Singnature      The pointer to the RSA PKCS1-V1_5 signature to be verifed.
+  @param[in]     Singnature      The pointer to the RSA PKCS1-V1_5 signature to be verified.
   @param[in]     SigSize         Size of signature in bytes.
 
   @retval  TRUE   Valid signature encoded in PKCS1-v1_5.
@@ -339,13 +339,13 @@ typedef struct _ENCRYPT_ALGORITHM {
 
 //
-// The struct used to store the information and operation of Autahentication algorithm.
+// The struct used to store the information and operation of Authentication algorithm.
 //
 typedef struct _AUTH_ALGORITHM {
-- 
2.10.1



  parent reply	other threads:[~2016-10-19  7:03 UTC|newest]

Thread overview: 79+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-10-19  7:01 [PATCH 00/33] Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 01/33] ArmPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19 15:15     ` Laszlo Ersek
2016-10-19 15:33       ` Leif Lindholm
2016-10-19  7:01 ` [PATCH 02/33] BaseTools: Fix typos in comments and variables Gary Lin
2016-10-19  7:30   ` Gao, Liming
2016-10-19  7:36   ` Zhu, Yonghong
2016-10-19  7:01 ` [PATCH 03/33] CorebootPayloadPkg: Fix typos in comments Gary Lin
2016-10-26 18:50   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 04/33] CorebootModulePkg: " Gary Lin
2016-10-26 18:41   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 05/33] CryptoPkg: " Gary Lin
2016-10-26  3:00   ` Long, Qin
2016-10-19  7:01 ` [PATCH 06/33] DuetPkg: " Gary Lin
2016-10-19  7:46   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 07/33] EdkCompatibilityPkg: " Gary Lin
2016-10-19  8:19   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 08/33] EmulatorPkg: Fix typos in comments and variables Gary Lin
2016-10-19 20:37   ` Jordan Justen
2016-10-20  8:16     ` Laszlo Ersek
2016-10-19  7:01 ` [PATCH 09/33] EmbeddedPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19  7:01 ` [PATCH 10/33] IntelFrameworkModulePkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 11/33] IntelFrameworkPkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 12/33] IntelFspPkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 13/33] IntelFspWrapperPkg: " Gary Lin
2016-10-19  7:08   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 14/33] IntelFsp2Pkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:12   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 15/33] IntelFsp2WrapperPkg: Fix a typo in the comment Gary Lin
2016-10-19  7:07   ` Yao, Jiewen
2016-10-19  7:11   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 16/33] MdeModulePkg: BootManagerMenuApp: Fix typos in comments Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 17/33] MdeModulePkg/Bus: " Gary Lin
2016-10-19  7:01 ` [PATCH 18/33] MdeModulePkg/Core: " Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 19/33] MdeModulePkg/Include: " Gary Lin
2016-10-19  7:01 ` [PATCH 20/33] MdeModulePkg/Library: Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 21/33] MdeModulePkg/Universal: Fix typos in comments Gary Lin
2016-10-19  7:01 ` [PATCH 22/33] MdePkg: " Gary Lin
2016-10-19  8:21   ` Gao, Liming
2016-10-19  7:01 ` Gary Lin [this message]
2016-10-19  7:21   ` [PATCH 23/33] NetworkPkg: " Fu, Siyuan
2016-10-26  0:53   ` Fu, Siyuan
2016-10-19  7:01 ` [PATCH 24/33] Nt32Pkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:50   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 25/33] OptionRomPkg: Fix typos in comments Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 26/33] OvmfPkg: " Gary Lin
2016-10-19  7:01 ` [PATCH 27/33] QuarkPlatformPkg: " Gary Lin
2016-10-25 20:53   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 28/33] QuarkSocPkg: " Gary Lin
2016-10-25 21:00   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 29/33] SecurityPkg: " Gary Lin
2016-10-27  1:29   ` Zhang, Chao B
2016-11-14  3:12   ` Zhang, Chao B
2016-11-14  4:03     ` Gary Lin
2016-11-14  6:24       ` Gao, Liming
2016-11-14  8:30         ` Gary Lin
2016-10-19  7:01 ` [PATCH 30/33] ShellPkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19 20:29     ` Carsey, Jaben
2016-10-20  1:55       ` Gary Lin
2016-10-19  7:01 ` [PATCH 31/33] SourceLevelDebugPkg: Fix typos in comments Gary Lin
2016-10-19  7:46   ` Wu, Hao A
2016-10-19  7:01 ` [PATCH 32/33] UefiCpuPkg: " Gary Lin
2016-10-20  1:58   ` Fan, Jeff
2016-10-20  2:08     ` Gary Lin
2016-10-20  2:45       ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 33/33] Vlv2TbltDevicePkg: " Gary Lin
2016-10-24  1:33   ` Wei, David
2016-10-19  7:28 ` [PATCH 00/33] Fix typos in comments and variables Zeng, Star
2016-10-19 14:50 ` Leif Lindholm

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20161019070138.16424-24-glin@suse.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox